from setuptools import setup

setup(
    name='horoscope',
    version='1.0.5',
    description='Fetches and parses data from Ganeshaspeaks.',
    author='Tapasweni Pathak',
    author_email='tapaswenipathak@gmail.com',
    url='https://github.com/tapasweni-pathak/pyhoroscope',
    packages=['horoscope'],
    )
